""" # # -a, --archive archive mode; equals -rlptgoD (no -H,-A,-X) INCLUDES: -r -l -p -t -g -o -D DOESN'T INCLUDE: -H PRESERVE HARD LINKS -A preserve ACLs (implies --perms) -X --xattrs preserve extended attributes # -c, --checksum ⭐? skip based on checksum, not mod-time & size # # -D ⭐ # --devices preserve device files (super-user only) # --specials preserve special files # # -g preserve group # # -h output numbers in a human-readable format # # -H ⭐⭐ preserve hard links # # # -l ⭐⭐ copy symlinks as symlinks # # -o preserve owner # # -p preserve permissions # # --partial ⭐ keep partially transferred files # # --progress # # -r ⭐⭐⭐ recursive # # --stats # # -t ⭐ preserve modification times # # -v ⭐ verbose # # -W ⭐ copy files whole (without delta-xfer algorithm) # # -rlptgoD # -Prltvc """